/************************************************/
/*						*/
/*      Copyright:				*/
/*	 Jean-Marc Pigeon <jmp@safe.ca>	 2009	*/
/*						*/
/************************************************/
/* This program is free software; you can 	*/
/* redistribute it and/or modify it under the 	*/
/* terms of the GNU General Public License as	*/
/* published by the Free Software Foundation	*/
/* version 2 of the License			*/
/*						*/
/* This program is distributed in the hope that */
/* it will be useful, but WITHOUT ANY WARRANTY; */
/* without even the implied warranty of		*/
/* MERCHANTABILITY or FITNESS FOR A PARTICULAR	*/
/* PURPOSE.  See the GNU General Public License	*/
/* for more details.				*/
/*						*/
/* You should have received a copy of the GNU	*/
/* General Public License along with this 	*/
/* program; if not, write to the Free Software	*/
/* Foundation, Inc., 51 Franklin Street,	*/
/* Fifth Floor, Boston, MA  02110-1301, USA.	*/
/************************************************/
/*						*/
/*	Define sub level procedure to debug	*/
/*	memory problem				*/
/*						*/
/************************************************/
#ifndef DBGMEM
#define DBGMEM
#include	<stdlib.h>
#include	<stdarg.h>

/*defining boolean value			*/
typedef enum {false, true} bool;

/*define it at compile if you want to look for 	*/
/*memory leak, report is displayed each time	*/
/*dbg_dumpmem is called.			*/
#ifdef	DEBUG
#define DEBUGMEM
#endif

/*to activate Memory leak detector		*/
#define	DMTRUE	1	/*Boolean		*/
#define	DMFALSE	0	/*Boolean		*/

#ifdef DEBUGMEM
#ifndef DEBUG
#error "Caution, See dbgmem.h,"
#error "you should use DEBUGMEM in DEBUG compilation mode"
#endif
#define DMTRACE	DMTRUE	
#else
#define DMTRACE	DMFALSE	
#endif

#ifdef	DEBUGMEM	
#define	calloc		dbg_calloc
#define	malloc		dbg_malloc
#define	realloc		dbg_realloc
#define	free		dbg_free
#define	setenv		dbg_setenv
#define	unsetenv	dbg_unsetenv
#define	asprintf	dbg_asprintf
#define	vasprintf	dbg_vasprintf
#define	SYSfree		dbg_sysfree

#undef strdup
#define	strdup		dbg_strdup
#else
#define	SYSfree		free
#endif

extern int memleak;

extern void dbg_setcurpath(char *path);
extern void dbg_setcurbase(char *path);
extern void *dbg_malloc(size_t size);
extern void *dbg_calloc(size_t nmemb,size_t size);
extern void *dbg_realloc(void *ptr,size_t size);
extern char *dbg_strdup(const char *str);
extern void dbg_free(void *ptr);
extern int dbg_unsetenv(const char *name);
extern int dbg_setenv(const char *name,const char *value,int overwrite);
extern int dbg_vasprintf(char **strp, const char *fmt,va_list args);
extern int dbg_asprintf(char **strp, const char *fmt, ...);
extern void dbg_sysfree(void *ptr);
extern void dbg_dumpmem(const char *apname,const char *extension);
extern void dbg_setnoleak(int value);
#endif
